@@ -1,18 +1,8 @@
-/***************************************************************************
-
-    Copyright 2007 Jeremy Whiting <jpwhiting@kde.org>
-    Copyright 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2007 Jeremy Whiting <jpwhiting@kde.org>
+ * SPDX-FileCopyrightText: 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+ * SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KEDUVOCWORDTYPE_H
 #define KEDUVOCWORDTYPE_H
@@ -39,7 +29,7 @@ public:
     explicit KEduVocWordType(const QString& name, KEduVocWordType *parent = nullptr);
 
     /** destructor */
-    ~KEduVocWordType();
+    ~KEduVocWordType() override;
 
     /** assignment operator */
 //     KEduVocWordType& operator= ( const KEduVocWordType& );
